import { ArrowLeft, Crown, Eye, Heart, Instagram, Link, Mail, MapPin } from 'lucide-react';
import { useEffect, useState } from 'react';
import { Card, Table } from 'react-bootstrap';
import { useDispatch, useSelector } from 'react-redux';
import { useNavigate, useParams } from 'react-router-dom';
import { clearCreator, fetchCreatorDetail } from '../store/slices/creatorsSlice';
import { Bar, Doughnut } from 'react-chartjs-2';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

const data = {
    labels: ['Red', 'Blue', 'Green', 'Purple'],
    datasets: [
        {
            label: 'GMV',
            data: [12, 19, 5, 2],
            backgroundColor: ['rgba(217, 107, 139)', 'rgba(101, 105, 225)', 'rgba(93, 200, 179)', 'rgba(122, 87, 218)'],
        },
    ],
};

const options = {
    plugins: {
        legend: {
            display: true,
            position: 'right',
            align: 'end',
            labels: {
                usePointStyle: true,
                pointStyle: 'circle',
                boxWidth: 10,
                padding: 10,
                font: {
                    size: 14,
                },
                color: '#eee',
                generateLabels: (chart) => {
                    const dataset = chart.data.datasets[0];
                    return chart.data.labels.map((label, i) => ({
                        text: `${label}  ${dataset.data[i]}%`,
                        fillStyle: dataset.backgroundColor[i],
                        strokeStyle: dataset.backgroundColor[i],
                        fontColor: '#000',
                        lineWidth: 0,
                    }));
                },
            },
        },
        tooltip: {
            callbacks: {
                label: (context) => `${context.label}: ${context.raw}%`,
            },
        },
    },
};

export default function CreatorDetail({}) {
    const { id } = useParams();
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const { selectedCreator, status } = useSelector((state) => state.creators);
    const [activeTab, setActiveTab] = useState('basic');

    const handleBack = () => {
        navigate(-1);
    };

    useEffect(() => {
        dispatch(fetchCreatorDetail({ creatorId: id }));
        return () => {
            dispatch(clearCreator());
        };
    }, [dispatch, id]);

    const processChartData = (data, chart) => {
        switch (chart) {
            case 'channel':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'GMV',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                            ],
                        },
                    ],
                };
            case 'category':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'Sold',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                            ],
                        },
                    ],
                };
        }
    };
    if (status === 'loading') {
        return <div>Loading...</div>;
    }
    if (status === 'failed') {
        return <div>Failed to load creator detail</div>;
    }

    if (!selectedCreator) {
        return <div>No creator found</div>;
    }

    return (
        <div className='creator-detail-page'>
            <div className='back-button' onClick={handleBack}>
                <ArrowLeft size={16} /> Go back
            </div>
            {selectedCreator ? (
                <div className='creator-info-detail-container'>
                    <div className='creator-info-container card'>
                        <div className='creator-info-1'>
                            <div className='creator-avatar'>
                                <img src={selectedCreator.creator.avatar} alt={selectedCreator.creator.name} />
                            </div>
                            <div className='creator-info-right'>
                                <div className='creator-name'>{selectedCreator.creator.name}</div>
                                <div className='creator-desc'>{selectedCreator?.description || '--'}</div>
                                <div className='creator-category'>{selectedCreator.business?.category || '--'}</div>
                                <div className='creator-location'>
                                    <MapPin size={16} />
                                    {selectedCreator.creator.location || ' --'}
                                </div>
                                <div className='creator-live-time'>{selectedCreator.live_schedule || '--'}</div>
                            </div>
                        </div>
                        <div className='creator-info-2'>
                            <div className='creator-info-item category-info'>
                                <div className='creator-info-label'>Category</div>
                                <div className='creator-info-value'>
                                    {selectedCreator.business?.categories.map((item, index) => (
                                        <span className='category-item badge' key={index}>
                                            {item}
                                        </span>
                                    ))}
                                </div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>MCN</div>
                                <div className='creator-info-value'>{selectedCreator.business?.mcn || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>Pricing</div>
                                <div className='creator-info-value'>
                                    {selectedCreator.business?.pricing?.range || '--'}
                                </div>
                            </div>
                            <div className='creator-info-item collab-info'>
                                <div className='creator-info-label'>Collab.</div>
                                <div className='creator-info-value'>
                                    <span className='collab-count'>
                                        {selectedCreator.business?.collab_count || '--'}
                                    </span>
                                    <span className='latest-collab badge'>
                                        {selectedCreator.business?.latest_collab || '--'}
                                    </span>
                                </div>
                            </div>
                        </div>
                        <div className='creator-info-3'>
                            <div className='creator-info-item'>
                                <div className='creator-info-label mail'>
                                    <Mail size={18} />
                                </div>
                                <div className='creator-info-value'>{selectedCreator.creator.email || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label social'>
                                    <Instagram size={18} />
                                </div>
                                <div className='creator-info-value'>
                                    {selectedCreator.creator.social_accounts?.instagram || '--'}
                                </div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label link'>
                                    <Link size={18} />
                                </div>
                                <div className='creator-info-value'>
                                    {selectedCreator.creator.social_accounts?.tiktok || '--'}
                                </div>
                            </div>
                        </div>
                    </div>
                    <div className='creator-data card'>
                        <div className='levels'>
                            <div className='level-item'>
                                <div className='name'>E-commerce Level</div>
                                <div className='value'>{selectedCreator?.metrics?.e_commerce_level || '--'}</div>
                            </div>
                            <div className='level-item'>
                                <div className='name'>Exposure Level</div>
                                <div className='value'>{selectedCreator?.metrics?.exposure_level || '--'}</div>
                            </div>
                        </div>
                        <div className='data-cards'>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.followers || '--'}</div>
                                <div className='name'>Followers</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.gmv || '--'}</div>
                                <div className='name'>GMV</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.avg_video_views || '--'}</div>
                                <div className='name'>Avg Video Views</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.items_sold || '--'}</div>
                                <div className='name'>Items Sold</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.gpm || '--'}</div>
                                <div className='name'>GPM</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.gmv_per_customer || '--'}</div>
                                <div className='name'>GMV per customer</div>
                            </div>
                        </div>
                        <div className='data-charts'>
                            <div className='data-chart'>
                                <div className='chart-title'>GMV per sales channel</div>
                                <Doughnut
                                    data={processChartData(selectedCreator?.analytics?.gmv_by_channel, 'channel')}
                                    options={{ ...options, cutout: 50 }}
                                />
                            </div>
                            <div className='data-chart'>
                                <div className='chart-title'>GMV by product category</div>
                                <Doughnut
                                    data={processChartData(selectedCreator?.analytics?.gmv_by_category, 'category')}
                                    options={{ ...options, cutout: 50 }}
                                />
                            </div>
                        </div>
                    </div>
                    <div className='creator-detail-tab-switches tab-switches'>
                        <div
                            className={`tab-switch-item ${activeTab === 'basic' ? 'active' : ''}`}
                            onClick={() => setActiveTab('basic')}
                        >
                            Basic Info
                        </div>
                        <div
                            className={`tab-switch-item ${activeTab === 'deepAnalysis' ? 'active' : ''}`}
                            onClick={() => setActiveTab('deepAnalysis')}
                        >
                            Deep Analysis
                        </div>
                        <div
                            className={`tab-switch-item ${activeTab === 'collab' ? 'active' : ''}`}
                            onClick={() => setActiveTab('collab')}
                        >
                            Collaboration Info
                        </div>
                    </div>
                    {activeTab === 'basic' && <CreatorBasicInfo selectedCreator={selectedCreator} />}
                    {activeTab === 'collab' && <CollabInfo selectedCreator={selectedCreator} />}
                </div>
            ) : (
                <div>No creator found</div>
            )}
        </div>
    );
}

function CreatorBasicInfo({ selectedCreator }) {
    const [activeTab, setActiveTab] = useState('gmv');
    const barOptions = {
        plugins: {
            legend: { display: false },
            tooltip: {
                callbacks: {
                    label: (context) => `${context.raw}%`,
                },
            },
            datalabels: {
                display: true,
                color: '#fff',
                anchor: 'end',
                align: 'start',
                formatter: (value) => `${value}%`,
            },
        },
        scales: {
            x: {
                grid: { display: false },
                ticks: {
                    color: '#888',
                    font: {
                        size: 14,
                    },
                },
            },
            y: {
                display: false,
            },
        },
    };

    const barData = {
        labels: ['TX', 'FL', 'NY', 'GE', 'CA'],
        datasets: [
            {
                label: 'Top 5 Locations',
                data: [11, 8, 6, 5.5, 5],
                backgroundColor: '#6C63FF',
                borderRadius: 10,
                barPercentage: 0.6,
            },
        ],
    };

    return (
        <div className='creator-basic-info card'>
            <div className='basic-info-list'>
                <div className='basic-info-title'>Collaboration Metrics</div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avg_commission_rate || '--'}</div>
                    <div className='name'>Avg. Commission Rate</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.products || '--'}</div>
                    <div className='name'>Products</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.brand_collaborations || '--'}</div>
                    <div className='name'>Brand Collaborations</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.product_price || '--'}</div>
                    <div className='name'>Product Price</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Video<span className='time-range'>{selectedCreator?.videoTimeRange || '--'}</span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoGpm || '--'}</div>
                    <div className='name'>Video GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.videos?.length || '--'}</div>
                    <div className='name'>Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoViews || '--'}</div>
                    <div className='name'>Avg. Video Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoEngagements || '--'}</div>
                    <div className='name'>Avg. Video Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoLikes || '--'}</div>
                    <div className='name'>Avg. Video Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Shoppable Video<span className='time-range'>{selectedCreator?.videoTimeRange || '--'}</span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoGpm || '--'}</div>
                    <div className='name'>Video GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.videos?.length || '--'}</div>
                    <div className='name'>Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoViews || '--'}</div>
                    <div className='name'>Avg. Video Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoEngagements || '--'}</div>
                    <div className='name'>Avg. Video Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgVideoLikes || '--'}</div>
                    <div className='name'>Avg. Video Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    LIVE<span className='time-range'>{selectedCreator?.liveTimeRange || '--'}</span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveGpm || '--'}</div>
                    <div className='name'>LIVE GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.liveVideos || '--'}</div>
                    <div className='name'>LIVE Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveViews || '--'}</div>
                    <div className='name'>Avg. LIVE Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveEngagements || '--'}</div>
                    <div className='name'>Avg. LIVE Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveLikes || '--'}</div>
                    <div className='name'>Avg. LIVE Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Shoppable LIVE<span className='time-range'>{selectedCreator?.liveTimeRange || '--'}</span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveGpm || '--'}</div>
                    <div className='name'>LIVE GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.liveVideos || '--'}</div>
                    <div className='name'>LIVE Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveViews || '--'}</div>
                    <div className='name'>Avg. LIVE Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveEngagements || '--'}</div>
                    <div className='name'>Avg. LIVE Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.avgLiveLikes || '--'}</div>
                    <div className='name'>Avg. LIVE Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Follwers<span className='time-range'>{selectedCreator?.liveTimeRange || '--'}</span>
                </div>
                <div className='followers-data-charts'>
                    <div className='data-chart'>
                        <div className='chart-title'>Follower Gender</div>
                        <Doughnut data={data} options={{ ...options, cutout: 60 }} />
                    </div>
                    <div className='data-chart'>
                        <div className='chart-title'>Follower Age</div>
                        <Doughnut data={data} options={{ ...options, cutout: 60 }} />
                    </div>
                    <div className='data-chart'>
                        <div className='chart-title'>Top 5 Locations</div>
                        <Bar data={barData} options={barOptions} />
                    </div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Trends<span className='time-range'>{selectedCreator?.liveTimeRange || '--'}</span>
                </div>
                <div className='tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'gmv' ? 'active' : ''}`}
                        onClick={() => setActiveTab('gmv')}
                    >
                        GMV
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'sold' ? 'active' : ''}`}
                        onClick={() => setActiveTab('sold')}
                    >
                        Items Sold
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'followers' ? 'active' : ''}`}
                        onClick={() => setActiveTab('followers')}
                    >
                        Followers
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'views' ? 'active' : ''}`}
                        onClick={() => setActiveTab('views')}
                    >
                        Video Views
                    </div>
                </div>
            </div>
            <div className='basic-info-list video-list'>
                <div className='basic-info-title'>Videos</div>
                {selectedCreator?.videos?.length > 0 &&
                    selectedCreator?.videos.map((video) => (
                        <div className='basic-info-item'>
                            <div className='picture' style={{ backgroundImage: `url(${video.picture})` }}></div>
                            <div className='right-side-info'>
                                <Crown size={16} />
                                <div className='video-title'>{video.title}</div>
                                <div className='release-time item-info'>
                                    Release Time<span className='time'>{video.releaseTime}</span>
                                </div>
                                <div className='views item-info'>
                                    <FontAwesomeIcon icon='fa-solid fa-eye' style={{ color: '#636AE8FF' }} />
                                    {video.views}
                                </div>
                                <div className='like item-info'>
                                    <FontAwesomeIcon icon='fa-solid fa-heart' style={{ color: '#E8618CFF' }} />
                                    {video.likes}
                                </div>
                            </div>
                        </div>
                    ))}

                <div className='basic-info-title'>Videos with Product</div>
                {selectedCreator?.videosWithProduct?.length > 0 &&
                    selectedCreator?.videosWithProduct.map((video) => (
                        <div className='basic-info-item'>
                            <div className='picture' style={{ backgroundImage: `url(${video.picture})` }}></div>
                            <div className='right-side-info'>
                                <Crown size={16} className='crown-icon' />
                                <div className='video-title'>{video.title}</div>
                                <div className='release-time item-info'>
                                    Release Time<span className='time'>{video.releaseTime}</span>
                                </div>
                                <div className='views item-info'>
                                    <FontAwesomeIcon icon='fa-solid fa-eye' style={{ color: '#636AE8FF' }} />
                                    {video.views}
                                </div>
                                <div className='like item-info'>
                                    <FontAwesomeIcon icon='fa-solid fa-heart' style={{ color: '#E8618CFF' }} />
                                    {video.likes}
                                </div>
                            </div>
                        </div>
                    ))}
            </div>
        </div>
    );
}

function CollabInfo({ selectedCreator }) {
    return (
        <div className='collab-info'>
            <Table responsive className='bg-white shadow-xs rounded overflow-hidden'>
                <thead>
                    <tr>
                        <th>Brand</th>
                        <th>Pricing Detail</th>
                        <th>Start Date</th>
                        <th>End Date</th>
                        <th>Status</th>
                        <th>GMV Achieved</th>
                        <th>Views Achieved</th>
                        <th>Video Link</th>
                    </tr>
                </thead>
                <tbody>
                    {selectedCreator?.collabInfo?.length > 0 ? (
                        selectedCreator?.collabInfo?.map((collab) => (
                            <tr>
                                <td>{collab.brand}</td>
                                <td>{collab.pricingDetail}</td>
                                <td>{collab.startDate}</td>
                                <td>{collab.endDate}</td>
                                <td>{collab.status}</td>
                            </tr>
                        ))
                    ) : (
                        <tr>
                            <td colSpan={8} className='text-center'>
                                No data
                            </td>
                        </tr>
                    )}
                </tbody>
            </Table>
        </div>
    );
}
